==> benchmark-api-1.9.3-sources.jar: org/opendaylight/yang/gen/v1/rpcbench/payload/rev150702/RoutedRpcBenchOutputBuilder.java <==
package org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.payload.Payload;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link RoutedRpcBenchOutputBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     RoutedRpcBenchOutputBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new RoutedRpcBenchOutputBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of RoutedRpcBenchOutputBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see RoutedRpcBenchOutputBuilder
 * @see Builder
 *
 */
public class RoutedRpcBenchOutputBuilder implements Builder<RoutedRpcBenchOutput> {

    private List<Payload> _payload;


    Map<Class<? extends Augmentation<RoutedRpcBenchOutput>>, Augmentation<RoutedRpcBenchOutput>> augmentation = Collections.emptyMap();

    public RoutedRpcBenchOutputBuilder() {
    }
    public RoutedRpcBenchOutputBuilder(org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload arg) {
        this._payload = arg.getPayload();
    }

    public RoutedRpcBenchOutputBuilder(RoutedRpcBenchOutput base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<RoutedRpcBenchOutput>>, Augmentation<RoutedRpcBenchOutput>> aug =((AugmentationHolder<RoutedRpcBenchOutput>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._payload = base.getPayload();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload) {
            this._payload = ((org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload)arg).getPayload();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload]");
    }

    public List<Payload> getPayload() {
        return _payload;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<RoutedRpcBenchOutput>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    public RoutedRpcBenchOutputBuilder setPayload(final List<Payload> values) {
        this._payload = values;
        return this;
    }
    
    
    public RoutedRpcBenchOutputBuilder addAugmentation(Class<? extends Augmentation<RoutedRpcBenchOutput>> augmentationType, Augmentation<RoutedRpcBenchOutput> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public RoutedRpcBenchOutputBuilder removeAugmentation(Class<? extends Augmentation<RoutedRpcBenchOutput>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public RoutedRpcBenchOutput build() {
        return new RoutedRpcBenchOutputImpl(this);
    }

    private static final class RoutedRpcBenchOutputImpl
        extends AbstractAugmentable<RoutedRpcBenchOutput>
        implements RoutedRpcBenchOutput {
    
        private final List<Payload> _payload;
    
        RoutedRpcBenchOutputImpl(RoutedRpcBenchOutputBuilder base) {
            super(base.augmentation);
            this._payload = base.getPayload();
        }
    
        @Override
        public List<Payload> getPayload() {
            return _payload;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_payload);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!RoutedRpcBenchOutput.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            RoutedRpcBenchOutput other = (RoutedRpcBenchOutput)obj;
            if (!Objects.equals(_payload, other.getPayload())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                RoutedRpcBenchOutputImpl otherImpl = (RoutedRpcBenchOutputImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<RoutedRpcBenchOutput>>, Augmentation<RoutedRpcBenchOutput>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("RoutedRpcBenchOutput");
            CodeHelpers.appendValue(helper, "_payload", _payload);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> benchmark-api-2.0.5-sources.jar: org/opendaylight/yang/gen/v1/rpcbench/payload/rev150702/RoutedRpcBenchOutputBuilder.java <==
package org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.payload.Payload;
import org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.payload.PayloadKey;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link RoutedRpcBenchOutputBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     RoutedRpcBenchOutputBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new RoutedRpcBenchOutputBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of RoutedRpcBenchOutputBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see RoutedRpcBenchOutputBuilder
 * @see Builder
 *
 */
public class RoutedRpcBenchOutputBuilder implements Builder<RoutedRpcBenchOutput> {

    private Map<PayloadKey, Payload> _payload;


    Map<Class<? extends Augmentation<RoutedRpcBenchOutput>>, Augmentation<RoutedRpcBenchOutput>> augmentation = Collections.emptyMap();

    public RoutedRpcBenchOutputBuilder() {
    }
    public RoutedRpcBenchOutputBuilder(org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload arg) {
        this._payload = arg.getPayload();
    }

    public RoutedRpcBenchOutputBuilder(RoutedRpcBenchOutput base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<RoutedRpcBenchOutput>>, Augmentation<RoutedRpcBenchOutput>> aug =((AugmentationHolder<RoutedRpcBenchOutput>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._payload = base.getPayload();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload) {
            this._payload = ((org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload)arg).getPayload();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload]");
    }

    public Map<PayloadKey, Payload> getPayload() {
        return _payload;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<RoutedRpcBenchOutput>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    public RoutedRpcBenchOutputBuilder setPayload(final Map<PayloadKey, Payload> values) {
        this._payload = values;
        return this;
    }
    
    /**
      * Utility migration setter.
      *
      * <b>IMPORTANT NOTE</b>: This method does not completely match previous mechanics, as the list is processed as
      *                        during this method's execution. Any future modifications of the list are <b>NOT</b>
      *                        reflected in this builder nor its products.
      *
      * @param values Legacy List of values
      * @return this builder
      * @throws IllegalArgumentException if the list contains entries with the same key
      * @throws NullPointerException if the list contains a null entry
      * @deprecated Use {#link #setPayload(Map)} instead.
      */
    @Deprecated(forRemoval = true)
    public RoutedRpcBenchOutputBuilder setPayload(final List<Payload> values) {
        return setPayload(CodeHelpers.compatMap(values));
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public RoutedRpcBenchOutputBuilder addAugmentation(Augmentation<RoutedRpcBenchOutput> augmentation) {
        return doAddAugmentation(augmentation.implementedInterface(), augmentation);
    }
    
    /**
      * Add or remove an augmentation to this builder's product.
      *
      * @param augmentationType augmentation type to be added or removed
      * @param augmentationValue augmentation value, null if the augmentation type should be removed
      * @return this builder
      * @deprecated Use either {@link #addAugmentation(Augmentation)} or {@link #removeAugmentation(Class)} instead.
      */
    @Deprecated(forRemoval = true)
    public RoutedRpcBenchOutputBuilder addAugmentation(Class<? extends Augmentation<RoutedRpcBenchOutput>> augmentationType, Augmentation<RoutedRpcBenchOutput> augmentationValue) {
        return augmentationValue == null ? removeAugmentation(augmentationType) : doAddAugmentation(augmentationType, augmentationValue);
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public RoutedRpcBenchOutputBuilder removeAugmentation(Class<? extends Augmentation<RoutedRpcBenchOutput>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }
    
    private RoutedRpcBenchOutputBuilder doAddAugmentation(Class<? extends Augmentation<RoutedRpcBenchOutput>> augmentationType, Augmentation<RoutedRpcBenchOutput> augmentationValue) {
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }

    @Override
    public RoutedRpcBenchOutput build() {
        return new RoutedRpcBenchOutputImpl(this);
    }

    private static final class RoutedRpcBenchOutputImpl
        extends AbstractAugmentable<RoutedRpcBenchOutput>
        implements RoutedRpcBenchOutput {
    
        private final Map<PayloadKey, Payload> _payload;
    
        RoutedRpcBenchOutputImpl(RoutedRpcBenchOutputBuilder base) {
            super(base.augmentation);
            this._payload = CodeHelpers.emptyToNull(base.getPayload());
        }
    
        @Override
        public Map<PayloadKey, Payload> getPayload() {
            return _payload;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_payload);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!RoutedRpcBenchOutput.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            RoutedRpcBenchOutput other = (RoutedRpcBenchOutput)obj;
            if (!Objects.equals(_payload, other.getPayload())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                RoutedRpcBenchOutputImpl otherImpl = (RoutedRpcBenchOutputImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<RoutedRpcBenchOutput>>, Augmentation<RoutedRpcBenchOutput>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("RoutedRpcBenchOutput");
            CodeHelpers.appendValue(helper, "_payload", _payload);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
